@@ -5,7 +5,7 @@ use Yahoo::BBAuth;
 use LWP;
 use XML::Simple;
 
-our $VERSION = '0.1';
+our $VERSION = '0.2';
 
 sub new {
     my $self = shift;
@@ -39,7 +39,8 @@ sub Bizsearch {
     my $param = shift;
     my $p = $param->{BizName};
     my $l = $param->{address};
-    my $request = $self->{request}."Biz.search?BizName=$p&address=$l";
+    my $page = $param->{page};
+    my $request = $self->{request}."Biz.search?BizName=$p&address=$l&page=$page";
     my $response = XMLin($self->_get($request));
     if ($response->{status} eq 'ok') {
 	return $response->{BizList};
@@ -183,6 +184,7 @@ sub _get {
 __END__
 
 =head1 NAME
+
 Yahoo::Lifestyle is a simple interface for Yahoo! Taiwan Lifestyle open APIs. And you will need the Yahoo::BBAuth for some authentication APIs. Before you use that, you have to register a appid and secret for APIs request.
 
 =head1 VERSION
@@ -195,7 +197,8 @@ January 16, 2008.
 use Yahoo::Lifestyle;
 
 $life = Yahoo::Lifestyle({ appid => "Ea6oQPHIkY03GklWeauQHWPpPJByMjCDoxRxcW"});
-$res = $life->Bizsearch({BizName => 'coffee', address => '');
+$res = $life->Bizsearch({BizName => 'coffee', address => '', page => '3');
+$list = $life->BizlistReviews({id => 'b4328e0fa8b25615', begin => '0', limit => '10');
 print $res->{Biz}->{$_}->{Name} for (keys %{$res});
 $life->bbauth({secret => $secret});
 $bookmarks = $life->UserlistBookmarks;
